#
# spec file for package libqca2
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libqca2
BuildRequires:  cmake
BuildRequires:  cyrus-sasl-devel
BuildRequires:  gpg2
BuildRequires:  kde4-filesystem
BuildRequires:  libdrm-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libqt4-devel
BuildRequires:  openssl-devel
BuildRequires:  update-desktop-files
Summary:        Qt Cryptographic Architecture 2
License:        LGPL-2.1+
Group:          Development/Libraries/C and C++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Url:            http://delta.affinix.com/qca/
Version:        2.0.3
Release:        20.4
%define tar_version %{version}
%define my_subdirs qca-gnupg-* qca-ossl-* qca-pkcs11-* qca-cyrus-sasl-*
%define with_botan 0
%define with_nss 0
%define with_pkcs11 1
%if %with_botan
BuildRequires:  libbotan-devel
%endif
%if %with_pkcs11
BuildRequires:  mozilla-nss-devel
%endif
%if %with_pkcs11
BuildRequires:  pkcs11-helper-devel
%endif
Source:         http://delta.affinix.com/download/qca/2.0/qca-%{tar_version}.tar.bz2
Source1:        http://delta.affinix.com/download/qca/2.0/plugins/qca-cyrus-sasl-2.0.0-beta3.tar.bz2
Source2:        http://delta.affinix.com/download/qca/2.0/plugins/qca-gnupg-2.0.0-beta3.tar.bz2
Source3:        http://delta.affinix.com/download/qca/2.0/plugins/qca-ossl-2.0.0-beta3.tar.bz2
Source4:        http://delta.affinix.com/download/qca/2.0/plugins/qca-pkcs11-2.0.0-beta2.tar.bz2
Source5:        baselibs.conf
Patch0:         fix-qt-check.diff
Patch1:         r928413.diff
Patch2:         disable-insecure-ssl.diff
Patch3:         qca-2.0.3-gcc47.patch
# PATCH-FIX-UPSTREAM detect_ssl2_available.diff -- fix build with no-ssl2 in openssl lib
Patch4:         detect_ssl2_available.diff
Patch5:         qca-no-ssl-internals.patch
Requires:       gpg2 >= 2.0.0
%requires_eq    libqt4

%description
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%package devel
Summary:        Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libqt4-devel

%description devel
This package provides a generic Qt cryptographic architecture,
including a library and a plugin for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES and AES.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%package plugin-cyrus-sasl
Summary:        Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description plugin-cyrus-sasl
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%if %with_botan

%package plugin-botan
Summary:        Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Provides:       %{name}:%{_libdir}/qt4/plugins/crypto/libqca-botan.so

%description plugin-botan
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%endif
%if %with_nss

%package plugin-nss
Summary:        Qt Cryptographic Architecture 2
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description plugin-nss
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%endif
%if %with_pkcs11

%package plugin-pkcs11
Summary:        Qt Cryptographic Architecture 2 - pkcs11 support
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description plugin-pkcs11
This package provides a generic Qt cryptographic architecture,
including a library and a plug-in for using all supported capabilities
of openssl, like SSL/TLS, X509, RSA, SHA1, MD5, Blowfish, 3DES, and
AES.

It can be extended by further plug-ins, for example, with qca-sasl for
SASL support.



Authors:
--------
    Justin Karneges <justin@affinix.com>

%endif

%prep
%setup -q -c -n qca-%{tar_version}/plugins -a 1 -a 2 -a 3 -a 4
pushd qca-gnupg-*
%patch0
popd
pushd qca-ossl-*
%patch2
%patch4 -p1
%patch5 -p3
popd
cd ../../..
%setup -D -q -n qca-%{tar_version}
%patch1
%patch3

%build
# I confess this is ugly..
# but there are too many "pro" files to make a patch ( > 180)
find -type f -name "*.pro" -exec sed -i "1i QMAKE_CXXFLAGS +=$RPM_OPT_FLAGS -DOPENSSL_NO_SSL_INTERN -DOPENSSL_LOAD_CONF -fvisibility-inlines-hidden" {} +
pushd plugins
rm -rf CMakeLists.txt qca-%{version}
for i in *; do
  echo "add_subdirectory($i)" >> CMakeLists.txt
done
popd
export CXXFLAGS="$RPM_OPT_FLAGS"
export CFLAGS="$RPM_OPT_FLAGS"
export EXTRA_FLAGS="$RPM_OPT_FLAGS -fvisibility-inlines-hidden -DOPENSSL_LOAD_CONF -DOPENSSL_NO_SSL_INTERN"
export QMAKE_CXXFLAGS="$EXTRA_FLAGS"
if [ %{_lib} = lib64 ]; then
  EXTRA_FLAGS="$EXTRA_FLAGS -DLIB_SUFFIX=64"
fi
#cmake . -DCMAKE_CXXFLAGS="$RPM_OPT_FLAGS" -DCMAKE_CFLAGS="$RPM_OPT_FLAGS" -DCMAKE_INSTALL_PREFIX=/usr $EXTRA_FLAGS
./configure --prefix=%{_prefix} --libdir=%{_libdir} --debug --no-separate-debug-info
make %{?jobs:-j %jobs}
export LD_LIBRARY_PATH=$PWD/lib
cd plugins
for sub in %{my_subdirs}; do
pushd $sub
  ./configure --debug --no-separate-debug-info --with-qca=$PWD/../.. --verbose
  make %{?jobs:-j %jobs}
popd
done

%install
make INSTALL_ROOT=$RPM_BUILD_ROOT install
rm apidocs/html/installdox
cd plugins
for sub in %{my_subdirs}; do
pushd $sub
  make INSTALL_ROOT=$RPM_BUILD_ROOT install
popd
done
mkdir -p $RPM_BUILD_ROOT%{_libdir}/pkgconfig

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT
# no baselibs supplements for older distros
%if %suse_version < 1110
  sed -i -e 's, supplements .*,,' $RPM_SOURCE_DIR/baselibs.conf
%endif

%files
%defattr(-,root,root)
%doc README COPYING TODO
%{_libdir}/libqca.so.*
%dir %{_libdir}/qt4/plugins/crypto
#%{_libdir}/qt4/plugins/crypto/libqca-logger.so
#%{_libdir}/qt4/plugins/crypto/libqca-softstore.so
%{_libdir}/qt4/plugins/crypto/libqca-ossl.so
%{_libdir}/qt4/plugins/crypto/libqca-gnupg.so
#%{_libdir}/qt4/plugins/crypto/libqca-gcrypt.so
%dir %{_datadir}/qca
%{_datadir}/qca/certs/

%files devel
%defattr(-,root,root)
%doc apidocs/html
%{_bindir}/qcatool2
%{_includedir}/QtCrypto
%{_datadir}/qt4/mkspecs/features/crypto.prf
%{_mandir}/man1/qcatool2*
%{_libdir}/libqca.so
%{_libdir}/libqca.prl
%{_libdir}/pkgconfig/qca2.pc

%files plugin-cyrus-sasl
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-cyrus-sasl.so
%if %with_botan

%files plugin-botan
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-botan.so
%endif
%if %with_nss

%files plugin-nss
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-nss.so
%endif
%if %with_pkcs11

%files plugin-pkcs11
%defattr(-,root,root)
%{_libdir}/qt4/plugins/crypto/libqca-pkcs11.so
%endif

%changelog
* Sat Apr 19 2014 crrodriguez@opensuse.org
- qca-no-ssl-internals.patch + spec file: Never use
  the ssl library internals directly, instead use the proper
  API accessors.
* Wed Apr 16 2014 hrvoje.senjan@gmail.com
- Added detect_ssl2_available.diff: fix build with no-ssl2 in
  openssl lib
* Fri Oct 11 2013 crrodriguez@opensuse.org
- build with -DOPENSSL_LOAD_CONF so QCA respects and uses
  the system's openSSL configuration.
* Thu Mar 15 2012 aj@suse.de
- Fix build with gcc 4.7.
* Sun Mar 11 2012 crrodriguez@opensuse.org
- Build respecting RPM_OPT_FLAGS, ugly hack to fix all
  * .pro files ensued.
- Build with visibility-inlines-hidden
* Thu Jun 23 2011 dmueller@suse.de
- update to 2.0.3:
  - Bugfix release, forward and backward compatible with 2.0.x
  - Fix compilation when using Qt/Windows SDK
* Thu Jun 23 2011 dmueller@suse.de
- remove dependency on botan now that it got broken
* Mon Apr 19 2010 dmueller@suse.de
- fix build when MD2 support is disabled (as default in openSSL 1.0.x)
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Sat Jul 11 2009 beineri@opensuse.org
- fix build on Factory by including upstream commit 864423:
  remove whirlpool hash usage. the algorithm is missing on at least
  0.9.8g/i/k, even though there is an OBJ_whirlpool definition
* Wed Jul  8 2009 dmueller@suse.de
- readd qt dependency
* Fri Jul  3 2009 prusnak@suse.cz
- updated to 2.0.2
  * Bugfix release, forward and backward compatible with 2.0.x
  * Fix compatibility with Qt 4.5 when QCA::Initializer appears before QApp
  * Don't convert to secure memory when Hash::update(QByteArray) is used
* Sun May  3 2009 dmueller@suse.de
- qt plugins need *exactly* the same Qt version
* Thu Feb 19 2009 dmueller@suse.de
- fix build with gcc 4.4
- fix build for older distros
- fix baselibs configuration
* Wed Feb 11 2009 ro@suse.de
- added libqca2 to baselibs.conf (required by plugins)
* Tue Feb  3 2009 dmueller@suse.de
- fix qt version check (bnc#471444)
* Thu Jan 22 2009 dmueller@suse.de
- add baselibs.conf
* Thu Aug 28 2008 wstephenson@suse.de
- update to 2.0.1
  * Bugfix release
  * the pkgconfig file is always qca2.pc, even in debug mode
  * Certificates containing wildcards are now matched properly
  * DirWatch/FileWatch now work
  * Keystore writes now work
  * Don't delete objects in their event handler (prevents Qt 4.4 warnings)
  * Fix potential hang with TLS in server mode
- improve packaging
* Mon Jul  7 2008 dmueller@suse.de
- update qca providers to latest beta release (bnc#379500)
* Sat Oct 20 2007 dmueller@suse.de
- only move the pkgconfig file for lib64 archs
* Thu Oct 18 2007 dmueller@suse.de
- build fix
* Thu Oct 18 2007 dmueller@suse.de
- improve packaging
* Wed Oct 17 2007 dmueller@suse.de
- update to 2.0.0 final:
  - Rewritten for Qt 4
  - MAC algorithms
  - DSA
  - Diffie-Hellman
  - Secure random
  - Secure memory
  - Extensive X.509 API, supporting chains, crls, and validation
  - Smart cards and other key storage
  - OpenPGP
  - Cryptographic Message Syntax (for S/MIME)
  - probably more
* Tue Aug 28 2007 dmueller@suse.de
- update to 2.0.0-test1:
  * finalized API
* Mon Aug  6 2007 aj@suse.de
- Botan-devel -> libbotan-devel
* Fri Aug  3 2007 dmueller@suse.de
- update to svn695914
- build plugins modular
- add nss, gcrypt, gnupg and cyrus-sasl plugins
* Mon Jun 25 2007 dmueller@suse.de
- update to svn revision680219
* Thu May 31 2007 dmueller@suse.de
- update to svn670229 to fix compilation with gcc 4.3
* Mon Apr 23 2007 dmueller@suse.de
- build against system Botan
* Thu Apr 19 2007 dmueller@suse.de
- spec file cleanup
* Sat Apr 14 2007 dmueller@suse.de
- fix build
* Wed Apr 11 2007 dmueller@suse.de
- fix -devel package requires
* Thu Apr  5 2007 dmueller@suse.de
- remove examples from devel package
* Tue Jan 23 2007 dmueller@suse.de
- fix build on lib64 platforms
* Mon Jan 22 2007 dmueller@suse.de
- Initial package (SVN r626102)
